@@ -140,10 +140,22 @@ describe "redis" do
 
   it 'should be able to use a namespace with setbit' do
     @namespaced.setbit('virgin_key', 1, 1)
-    expect(@namespaced.exists('virgin_key')).to be true
+    expect(@namespaced.exists?('virgin_key')).to be true
     expect(@namespaced.get('virgin_key')).to eq(@namespaced.getrange('virgin_key',0,-1))
   end
 
+  it 'should be able to use a namespace with exists' do
+    @namespaced.set('foo', 1000)
+    @namespaced.set('bar', 2000)
+    expect(@namespaced.exists('foo', 'bar')).to eq(2)
+  end
+
+  it 'should be able to use a namespace with exists?' do
+    @namespaced.set('foo', 1000)
+    @namespaced.set('bar', 2000)
+    expect(@namespaced.exists?('does_not_exist', 'bar')).to eq(true)
+  end
+
   it 'should be able to use a namespace with bitpos' do
     @namespaced.setbit('bit_map', 42, 1)
     expect(@namespaced.bitpos('bit_map', 0)).to eq(0)
@@ -239,7 +251,7 @@ describe "redis" do
     @namespaced.zadd('sort2', 2, 2)
     @namespaced.zadd('sort2', 3, 3)
     @namespaced.zadd('sort2', 4, 4)
-    @namespaced.zunionstore('union', ['sort1', 'sort2'], :weights => [2, 1])
+    @namespaced.zunionstore('union', ['sort1', 'sort2'], weights: [2, 1])
     expect(@namespaced.zrevrange('union', 0, -1)).to eq(%w( 2 4 3 1 ))
   end
 
@@ -442,6 +454,45 @@ describe "redis" do
     expect { @namespaced.unknown('foo') }.to raise_exception NoMethodError
   end
 
+  describe '#inspect' do
+    let(:single_level_names) { %i[first] }
+    let(:double_level_names) { %i[first second] }
+    let(:triple_level_names) { %i[first second third] }
+    let(:namespace_builder) do
+      ->(redis, *namespaces) { namespaces.reduce(redis) { |r, n| Redis::Namespace.new(n, redis: r) } }
+    end
+    let(:regexp_builder) do
+      ->(*namespaces) { %r{/#{namespaces.join(':')}>\z} }
+    end
+
+    context 'when one namespace' do
+      let(:single_namespaced) { namespace_builder.call(@redis, *single_level_names) }
+      let(:regexp) { regexp_builder.call(*single_level_names) }
+
+      it 'should have correct ending of inspect string' do
+        expect(regexp =~ single_namespaced.inspect).not_to be(nil)
+      end
+    end
+
+    context 'when two namespaces' do
+      let(:double_namespaced) { namespace_builder.call(@redis, *double_level_names) }
+      let(:regexp) { regexp_builder.call(*double_level_names) }
+
+      it 'should have correct ending of inspect string' do
+        expect(regexp =~ double_namespaced.inspect).not_to be(nil)
+      end
+    end
+
+    context 'when three namespaces' do
+      let(:triple_namespaced) { namespace_builder.call(@redis, *triple_level_names) }
+      let(:regexp) { regexp_builder.call(*triple_level_names) }
+
+      it 'should have correct ending of inspect string' do
+        expect(regexp =~ triple_namespaced.inspect).not_to be(nil)
+      end
+    end
+  end
+
   # Redis 2.6 RC reports its version as 2.5.
   if @redis_version >= Gem::Version.new("2.5.0")
     describe "redis 2.6 commands" do
